"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.otrsApiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
async function otrsApiRequest(method, path, uri, body, qs) {
    const credentials = await this.getCredentials('otrsAuthApi');
    const optionsAuth = {
        body: {
            User: credentials.username,
            Password: credentials.password,
        },
        uri: `${credentials.host}/api/auth/login`,
        json: true,
        method: 'POST',
    };
    const authRespo = await this.helpers.request(optionsAuth);
    if (authRespo["Response"].toLocaleLowerCase() !== "ok") {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), { "error": 401, "message": authRespo.Message }, { message: authRespo.Message, httpCode: "401" });
    }
    const sessionID = authRespo["SessionValue"];
    const options = {
        method,
        body,
        qs,
        uri: `${credentials.host}/nph-genericinterface.pl/Webservice/${credentials.path}/${path}`,
        json: true,
        rejectUnauthorized: false,
    };
    if (uri !== undefined) {
        options.uri = `${credentials.host}${uri}`;
    }
    options.body["SessionID"] = sessionID;
    if (typeof options.body === "undefined" || Object.keys(options.body).length < 1) {
        delete options.body;
    }
    if (typeof options.qs === "undefined" || Object.keys(options.qs).length < 1) {
        delete options.qs;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.otrsApiRequest = otrsApiRequest;
//# sourceMappingURL=GenericFunctions.js.map