"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Otrs = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const ResourceDescription_1 = require("./ResourceDescription");
const Operations_1 = require("./Ticket/Operations");
const Operations_2 = require("./Customer/Operations");
const Create_1 = require("./Ticket/Create");
const GenericFunctions_1 = require("./GenericFunctions");
const Create_2 = require("./Customer/Create");
class Otrs {
    constructor() {
        this.description = {
            displayName: 'Otrs',
            name: 'otrs',
            icon: 'file:otrs.svg',
            group: ['transform'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'OTRS Data Platform',
            defaults: {
                name: 'OTRS',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [{
                    name: 'otrsAuthApi',
                    required: true,
                }],
            properties: [
                ...ResourceDescription_1.otrsResource,
                ...Operations_1.ticketOperations,
                ...Create_1.ticketCreateFields,
                ...Create_1.optionalTicketCreateFields,
                ...Operations_2.customerOperations,
                ...Create_2.customerCreateFields,
            ],
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const resource = this.getNodeParameter('resource', 0);
        const operation = this.getNodeParameter('operation', 0);
        const body = {};
        const qs = {};
        for (let i = 0; i < items.length; i++) {
            try {
                if (resource === 'ticket') {
                    if (operation === 'create') {
                        const ticket = {
                            'Title': this.getNodeParameter('title', i),
                            'CustomerUser': this.getNodeParameter('customerUser', i),
                        };
                        const article = {
                            'CommunicationChannel': 'Email',
                            'Subject': this.getNodeParameter('subject', i),
                            'Body': this.getNodeParameter('body', i),
                            'ContentType': 'text/plain; charset=utf8',
                            'Charset': 'utf8',
                            'MimeType': 'text/plain',
                        };
                        const additionalFields = this.getNodeParameter('additionalFields', i);
                        if (typeof additionalFields.customerID !== 'undefined') {
                            ticket["CustomerID"] = additionalFields.customerID;
                        }
                        if (typeof additionalFields.queueID !== 'undefined') {
                            ticket["QueueID"] = additionalFields.queueID;
                        }
                        if (typeof additionalFields.queue !== 'undefined') {
                            ticket["Queue"] = additionalFields.queue;
                        }
                        if (typeof additionalFields.stateID !== 'undefined') {
                            ticket["StateID"] = additionalFields.stateID;
                        }
                        if (typeof additionalFields.state !== 'undefined') {
                            ticket["State"] = additionalFields.state;
                        }
                        if (typeof additionalFields.priorityID !== 'undefined') {
                            ticket["PriorityID"] = additionalFields.priorityID;
                        }
                        if (typeof additionalFields.priority !== 'undefined') {
                            ticket["Priority"] = additionalFields.priority;
                        }
                        if (typeof additionalFields.lockID !== 'undefined') {
                            ticket["LockID"] = additionalFields.lockID;
                        }
                        if (typeof additionalFields.lock !== 'undefined') {
                            ticket["Lock"] = additionalFields.lock;
                        }
                        if (typeof additionalFields.ticketTypeID !== 'undefined') {
                            ticket["TypeID"] = additionalFields.ticketTypeID;
                        }
                        if (typeof additionalFields.ticketType !== 'undefined') {
                            ticket["Type"] = additionalFields.ticketType;
                        }
                        if (typeof additionalFields.serviceID !== 'undefined') {
                            ticket["ServiceID"] = additionalFields.serviceID;
                        }
                        if (typeof additionalFields.service !== 'undefined') {
                            ticket["Service"] = additionalFields.service;
                        }
                        if (typeof additionalFields.SLAID !== 'undefined') {
                            ticket["SLAID"] = additionalFields.SLAID;
                        }
                        if (typeof additionalFields.SLA !== 'undefined') {
                            ticket["SLA"] = additionalFields.SLA;
                        }
                        if (typeof additionalFields.ownerID !== 'undefined') {
                            ticket["OwnerID"] = additionalFields.ownerID;
                        }
                        if (typeof additionalFields.owner !== 'undefined') {
                            ticket["Owner"] = additionalFields.owner;
                        }
                        if (typeof additionalFields.responsibleID !== 'undefined') {
                            ticket["ResponsibleID"] = additionalFields.responsibleID;
                        }
                        if (typeof additionalFields.responsible !== 'undefined') {
                            ticket["Responsible"] = additionalFields.responsible;
                        }
                        if (typeof additionalFields.isVisibleForCustomer !== 'undefined') {
                            article["IsVisibleForCustomer"] = additionalFields.isVisibleForCustomer;
                        }
                        if (typeof additionalFields.senderTypeID !== 'undefined') {
                            article["SenderTypeID"] = additionalFields.senderTypeID;
                        }
                        if (typeof additionalFields.senderType !== 'undefined') {
                            article["SenderType"] = additionalFields.senderType;
                        }
                        if (typeof additionalFields.autoResponseType !== 'undefined') {
                            article["AutoResponseType"] = additionalFields.autoResponseType;
                        }
                        if (typeof additionalFields.from !== 'undefined') {
                            article["From"] = additionalFields.from;
                        }
                        if (typeof additionalFields.historyType !== 'undefined') {
                            article["HistoryType"] = additionalFields.historyType;
                        }
                        if (typeof additionalFields.historyComment !== 'undefined') {
                            article["HistoryComment"] = additionalFields.historyComment;
                        }
                        if (typeof additionalFields.timeUnit !== 'undefined') {
                            article["TimeUnit"] = additionalFields.timeUnit;
                        }
                        if (typeof additionalFields.noAgentNotify !== 'undefined') {
                            article["NoAgentNotify"] = additionalFields.noAgentNotify;
                        }
                        body["Ticket"] = ticket;
                        body["Article"] = article;
                        const responseData = await GenericFunctions_1.otrsApiRequest.call(this, 'POST', `ticket`, undefined, body);
                        returnData.push(responseData);
                    }
                    else {
                        throw new n8n_workflow_1.NodeOperationError(this.getNode(), `The operation "${operation}" is not known!`);
                    }
                }
                else if (resource === 'customer') {
                    if (operation === 'create') {
                        const customer = {
                            'Firstname': this.getNodeParameter('firstname', i),
                            'Lastname': this.getNodeParameter('lastname', i),
                            'CustomerID': this.getNodeParameter('email', i),
                            'Login': this.getNodeParameter('email', i),
                            'Email': this.getNodeParameter('email', i),
                        };
                        const responseData = await GenericFunctions_1.otrsApiRequest.call(this, `POST`, undefined, '/api/customers/createCustomerUser', customer);
                        returnData.push(responseData);
                    }
                    else {
                        throw new n8n_workflow_1.NodeOperationError(this.getNode(), `The operation "${operation}" is not known!`);
                    }
                }
                else {
                    throw new n8n_workflow_1.NodeOperationError(this.getNode(), `The resource "${resource}" is not known!`);
                }
            }
            catch (error) {
                if (this.continueOnFail()) {
                    returnData.push({ error: error.message });
                    continue;
                }
                throw error;
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.Otrs = Otrs;
//# sourceMappingURL=Otrs.node.js.map